@@ -2,9 +2,13 @@ package Crypt::Perl::ASN1;
 
 #Wrappers around basic methods to get exceptions thrown on errors.
 
+use strict;
+use warnings;
+
 use parent 'Convert::ASN1';
 
 use Crypt::Perl::BigInt ();
+use Crypt::Perl::X ();
 
 sub new {
     my ($class, @opts) = @_;
@@ -22,7 +26,7 @@ sub prepare {
     my $ret = $self->SUPER::prepare($$asn1_r);
 
     if ( !defined $ret ) {
-        die sprintf( "Failed to prepare ASN.1 description: %s", $self->error() );
+        die Crypt::Perl::X::create('ASN1::Prepare', $$asn1_r, $self->error());
     }
 
     return $ret;
@@ -32,7 +36,7 @@ sub find {
     my ( $self, $macro ) = @_;
 
     return $self->SUPER::find($macro) || do {
-        die sprintf( "Failed to find ASN.1 macro “$macro”: %s", $self->error() );
+        die Crypt::Perl::X::create('ASN1::Find', $macro, $self->error());
     };
 }
 
@@ -40,15 +44,15 @@ sub encode {
     my ($self) = shift;
 
     return $self->SUPER::encode(@_) || do {
-        die sprintf( "Failed to encode ASN.1 (args: @_): %s", $self->error() );
+        die Crypt::Perl::X::create('ASN1::Encode', \@_, $self->error());
     };
 }
 
 sub decode {
     my ($self) = shift;
 
-    return $self->SUPER::decode(@_) || do {
-        die sprintf( "Failed to decode ASN.1 (@_): %s", $self->error() );
+    return $self->SUPER::decode($_[0]) || do {
+        die Crypt::Perl::X::create('ASN1::Decode', $_[0], $self->error());
     };
 }
 
