@@ -142,6 +142,30 @@ sub get_public_key {
     } );
 }
 
+sub get_struct_for_private_jwk {
+    my ($self) = @_;
+
+    Module::Load::load('MIME::Base64');
+
+    my $jwk = $self->get_struct_for_public_jwk();
+
+    my %augment = qw(
+        d   D
+        p   P
+        q   Q
+        dp  DP
+        dq  DQ
+        qi  QINV
+    );
+
+    for my $k (keys %augment) {
+        my $accessor = $augment{$k};
+        $jwk->{$k} = MIME::Base64::encode_base64url( $self->$accessor()->as_bytes() );
+    }
+
+    return $jwk;
+}
+
 #----------------------------------------------------------------------
 #This function, in tandem with encrypt_raw(), represents the fundamental
 #mathematical truth on which RSA rests.
@@ -223,29 +247,26 @@ sub _transform {
         $r = Crypt::Perl::BigInt->from_hex(
             Crypt::Perl::RNG::bytes_hex( $key_bytes_length ),
         );
-    } while ($r >= $self->N()) || ($r->bgcd($self->N()) != 1);
+    } while ($r->bge($self->N())) || ($r->bgcd($self->N())->bne(1));
 
-    $x *= $r->copy()->bmodpow($self->E(), $self->N());
-    $x %= $self->N();
+    $x->bmul( $r->copy()->bmodpow($self->E(), $self->N()) )->bmod($self->N());
 
     #calculate xp and xq
-    my $xp = ($x % $self->P())->bmodpow($self->DP(), $self->P());
-    my $xq = ($x % $self->Q())->bmodpow($self->DQ(), $self->Q());
+    my $xp = $x->copy()->bmod($self->P())->bmodpow($self->DP(), $self->P());
+    my $xq = $x->copy()->bmod($self->Q())->bmodpow($self->DQ(), $self->Q());
 
     #xp must be larger than xq to avoid signed bit usage
-    while ($xp < $xq) {
-        $xp += $self->P();
-    }
+    $xp->badd($self->P()) while $xp->blt($xq);
 
-    my $y = $xp - $xq;
-    $y *= $self->QINV();
-    $y %= $self->P();
-    $y *= $self->Q();
-    $y += $xq;
+    my $y = $xp->bsub($xq)->bmul($self->QINV())->bmod($self->P());
+
+    #$y *= $self->Q();
+    #$y += $xq;
+    $y->bmuladd( $self->Q(), $xq );
 
     #remove effect of random for cryptographic blinding
-    $y *= $r->bmodinv($self->N());
-    $y %= $self->N();
+    $y->bmul( $r->bmodinv($self->N()) );
+    $y->bmod($self->N());
 
     return $y;
 }
