@@ -5,6 +5,8 @@ use warnings;
 
 use Test::More;
 
+use File::Which ();
+
 sub SKIP_CLASS {
     my ($self) = @_;
 
@@ -17,12 +19,12 @@ sub _get_openssl {
     my ($self) = @_;
 
     return $self->{'_ossl_bin'} ||= do {
-        my $bin = `which openssl`;
-        die if $?;
-        chomp $bin;
+        my $bin = File::Which::which('openssl');
 
-        note "Using OpenSSL binary: $bin";
-        note `$bin version -a`;
+        if ($bin) {
+            note "Using OpenSSL binary: $bin";
+            note `$bin version -a`;
+        }
 
         $bin;
     };
